*************************************************
:mod:`mopidy.mixers.alsa` -- ALSA mixer for Linux
*************************************************

.. inheritance-diagram:: mopidy.mixers.alsa

.. automodule:: mopidy.mixers.alsa
    :synopsis: ALSA mixer for Linux
    :members:
